#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-01-07
#

#
# 2021-01-07: added short names
#

from cmk.gui.i18n import _
from cmk.gui.plugins.views import (
    inventory_displayhints,
)
from cmk.gui.plugins.views.inventory import declare_invtable_view

inventory_displayhints.update({
    '.software.cve_2021_44228_log4j': {
        'title': _('CVE Scanner for log4j (CVE-2021-44228-log4j)'),
    },
    '.software.cve_2021_44228_log4j.summary:': {
        'title': _('Summary'),
        'keyorder': [
            'index',
            'files_vulnerable',
            'files_potential_vulnerable',
            'files_mitigated',
            'files_skipped',
            'errors',
            'files_scanned',
            'directories_scanned',
            'run_time',
            'last_run',
            'scanner_version',
            'script_version',
            'bakery_version',
            'scan_options',
        ],
        'view': 'invcve202144228log4jsummary_of_host',
    },
    '.software.cve_2021_44228_log4j.summary:*.index': {'title': _('Index'), },
    '.software.cve_2021_44228_log4j.summary:*.files_vulnerable': {'title': _('Files vulnerable'), 'short': _('Vulnerable'), },
    '.software.cve_2021_44228_log4j.summary:*.files_potential_vulnerable': {'title': _('Files potentially vulnerable'), 'short': _('Potentially'), },
    '.software.cve_2021_44228_log4j.summary:*.files_mitigated': {'title': _('Files mitigated'), 'short': _('Mitigated'), },
    '.software.cve_2021_44228_log4j.summary:*.files_scanned': {'title': _('Files scanned'), 'short': _('Files'), },
    '.software.cve_2021_44228_log4j.summary:*.files_skipped': {'title': _('Files skipped'), 'short': _('Skipped'), },
    '.software.cve_2021_44228_log4j.summary:*.directories_scanned': {'title': _('Directories scanned'), 'short': _('Directories'), },
    '.software.cve_2021_44228_log4j.summary:*.run_time': {'title': _('Run time'), },
    '.software.cve_2021_44228_log4j.summary:*.last_run': {'title': _('Last run'), },
    '.software.cve_2021_44228_log4j.summary:*.errors': {'title': _('Errors'), },
    '.software.cve_2021_44228_log4j.summary:*.scanner_version': {'title': _('logresso scanner version'), 'short': _('Scanner version'), },
    '.software.cve_2021_44228_log4j.summary:*.scan_options': {'title': _('Scan options'), },
    '.software.cve_2021_44228_log4j.summary:*.script_version': {'title': _('Script version'), },
    '.software.cve_2021_44228_log4j.summary:*.bakery_version': {'title': _('Bakery version'), },

    '.software.cve_2021_44228_log4j.report:': {
        'title': _('Report'),
        'keyorder': [
            'index',
            'time',
            'cve',
            'status',
            'fixed',
            'product',
            'version',
            # 'hostname',
            'path',
            'error',
            'entry',
        ],
        'view': 'invcve202144228log4jreport_of_host',
    },
    '.software.cve_2021_44228_log4j.report:*.index': {'title': _('Index'), },
    '.software.cve_2021_44228_log4j.report:*.time': {'title': _('Time'), },
    '.software.cve_2021_44228_log4j.report:*.cve': {'title': _('CVE'), },
    '.software.cve_2021_44228_log4j.report:*.status': {'title': _('Status'), },
    '.software.cve_2021_44228_log4j.report:*.fixed': {'title': _('Fixed'), },
    '.software.cve_2021_44228_log4j.report:*.product': {'title': _('Product'), },
    '.software.cve_2021_44228_log4j.report:*.version': {'title': _('Version'), },
    # '.software.cve_2021_44228_log4j.report:*.hostname': {'title': _('Hostname'), },
    '.software.cve_2021_44228_log4j.report:*.path': {'title': _('Path'), },
    '.software.cve_2021_44228_log4j.report:*.entry': {'title': _('Entry'), },
    '.software.cve_2021_44228_log4j.report:*.error': {'title': _('Error'), },
})

declare_invtable_view(
    'invcve202144228log4jsummary',
    '.software.cve_2021_44228_log4j.summary:',
    _('CVE Scanner for log4j summary'),
    _('CVE Scanner for log4j summary'),
)

declare_invtable_view(
    'invcve202144228log4jreport',
    '.software.cve_2021_44228_log4j.report:',
    _('CVE Scanner for log4j report'),
    _('CVE Scanner for log4j report'),
)